==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/RateOfChangeAndMomentumIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RateOfChangeAndMomentumIndicatorStrategy } from "./RateOfChangeAndMomentumIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var RateOfChangeAndMomentumIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RateOfChangeAndMomentumIndicator, _super);
    function RateOfChangeAndMomentumIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RateOfChangeAndMomentumIndicator.prototype.get_ul = function () {
        return new RateOfChangeAndMomentumIndicatorStrategy();
    };
    Object.defineProperty(RateOfChangeAndMomentumIndicator.prototype, "ul", {
        get: function () {
            return this.get_ul();
        },
        enumerable: false,
        configurable: true
    });
    RateOfChangeAndMomentumIndicator.prototype.get_uy = function () {
        return RateOfChangeAndMomentumIndicator.$;
    };
    Object.defineProperty(RateOfChangeAndMomentumIndicator.prototype, "uy", {
        get: function () {
            return this.get_uy();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RateOfChangeAndMomentumIndicator.prototype, "u6", {
        get: function () {
            return typeGetValue(this.c(RateOfChangeAndMomentumIndicator.u7));
        },
        set: function (a) {
            this.h(RateOfChangeAndMomentumIndicator.u7, a);
        },
        enumerable: false,
        configurable: true
    });
    RateOfChangeAndMomentumIndicator.prototype.ur = function () {
        return this.u6;
    };
    RateOfChangeAndMomentumIndicator.prototype.u0 = function (a) {
        this.u6 = a;
    };
    RateOfChangeAndMomentumIndicator.$t = markType(RateOfChangeAndMomentumIndicator, 'RateOfChangeAndMomentumIndicator', StrategyBasedIndicator.$);
    RateOfChangeAndMomentumIndicator.u7 = StrategyBasedIndicator.u3(14, RateOfChangeAndMomentumIndicator.$);
    return RateOfChangeAndMomentumIndicator;
}(StrategyBasedIndicator));
export { RateOfChangeAndMomentumIndicator };

==> igniteui-react-charts-18.5.1.tgz: package/esm5/lib/RateOfChangeAndMomentumIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RateOfChangeAndMomentumIndicatorStrategy } from "./RateOfChangeAndMomentumIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var RateOfChangeAndMomentumIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RateOfChangeAndMomentumIndicator, _super);
    function RateOfChangeAndMomentumIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RateOfChangeAndMomentumIndicator.prototype.bg = function () {
        return new RateOfChangeAndMomentumIndicator();
    };
    RateOfChangeAndMomentumIndicator.prototype.get_yz = function () {
        return new RateOfChangeAndMomentumIndicatorStrategy();
    };
    Object.defineProperty(RateOfChangeAndMomentumIndicator.prototype, "yz", {
        get: function () {
            return this.get_yz();
        },
        enumerable: false,
        configurable: true
    });
    RateOfChangeAndMomentumIndicator.prototype.get_zc = function () {
        return RateOfChangeAndMomentumIndicator.$;
    };
    Object.defineProperty(RateOfChangeAndMomentumIndicator.prototype, "zc", {
        get: function () {
            return this.get_zc();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RateOfChangeAndMomentumIndicator.prototype, "zk", {
        get: function () {
            return typeGetValue(this.c(RateOfChangeAndMomentumIndicator.zl));
        },
        set: function (a) {
            this.h(RateOfChangeAndMomentumIndicator.zl, a);
        },
        enumerable: false,
        configurable: true
    });
    RateOfChangeAndMomentumIndicator.prototype.y5 = function () {
        return this.zk;
    };
    RateOfChangeAndMomentumIndicator.prototype.ze = function (a) {
        this.zk = a;
    };
    RateOfChangeAndMomentumIndicator.$t = markType(RateOfChangeAndMomentumIndicator, 'RateOfChangeAndMomentumIndicator', StrategyBasedIndicator.$);
    RateOfChangeAndMomentumIndicator.zl = StrategyBasedIndicator.zh(14, RateOfChangeAndMomentumIndicator.$);
    return RateOfChangeAndMomentumIndicator;
}(StrategyBasedIndicator));
export { RateOfChangeAndMomentumIndicator };
